package com.devexperts.mdd.news.event;

import java.util.HashSet;
import java.util.Set;

/**
 * Common news tags names.
 */
public class NewsTags
{
    public static final String SYMBOLS = "Symbols";
    public static final String KEYWORDS = "Keywords";
    public static final String CORRECTION = "Correction";

    // NewsSummary class is not modified to keep compatibility with dxFeed News API (through serialization)
    // System fields are sent via NewsSummary tags (they are specially handled by news services)

    // Optional field that contains raw news meta information
    public static final String CONTENT_META = "_meta";
    // Required field that contains raw news data
    public static final String CONTENT_NEWS = "_news";
    // Required field that contains news feed name
    public static final String NEWS_FEED = "_feed";

    // Meta tags that contain news+meta in the original (unparsed) format
    public static final Set<String> META_TAGS = new HashSet<>();
    static {
        META_TAGS.add(CONTENT_META);
        META_TAGS.add(CONTENT_NEWS);
    }

    // Tags that are persisted as fields (in NEWS table) and not as tags (in NEWS_KEYWORDS table)
    public static final Set<String> FIELD_TAGS = new HashSet<>();
    static {
        FIELD_TAGS.add(NEWS_FEED);
        FIELD_TAGS.addAll(META_TAGS);
    }

    // Tags that should be in the news when persisting it
    public static final Set<String> PERSISTENT_TAGS = new HashSet<>();
    static {
        PERSISTENT_TAGS.add(SYMBOLS);
        PERSISTENT_TAGS.add(CORRECTION);
        PERSISTENT_TAGS.addAll(FIELD_TAGS);
    }

    // Utility class only
    private NewsTags() {}
}
